# Fair use

If you use Sigmund very heavily, you may receive a warning that you exceeded your weekly usage limit. Don't worry! This is a soft limit, which means you can continue to use Sigmund. However, when this happens, we kindly ask that you use Sigmund a bit less!

Here are some tricks to reduce your usage of Sigmund:

- __Do more with fewer prompts.__ You can get Sigmund to work more effectively by taking a moment to formulate good prompts.
- __Use a conversation model.__ Most tasks do not require a problem-solving model such as Claude Opus. Conversation models are more cost-effective.
- __Try Mistral Large.__ This is by far the most cost-effective model. It is not as smart as the models from OpenAI and Anthropic. However, it will perform many complex tasks just fine!

Usage is calculated over seven days. If you reduce your use of Sigmund now, the usage-limit warning will automatically disappear after a few days. 

Remember: we rely on your cooperation to keep Sigmund affordable!
